import argparse
import os
import boto3

parser = argparse.ArgumentParser()
subparser = parser.add_subparsers()

accolade_group = subparser.add_parser('accolade')
accolade_subparser = accolade_group.add_subparsers()

accolade_storage = accolade_subparser.add_parser('storage')
accolade_subparser2 = accolade_storage.add_subparsers()

accolade_move = accolade_subparser2.add_parser('move')
accolade_move.set_defaults(which='move')
accolade_move.add_argument('mfile', help="File being moved")
accolade_move.add_argument('mfolder', help="Place being added")

accolade_copy = accolade_subparser2.add_parser('copy')
accolade_copy.set_defaults(which='copy')
accolade_copy.add_argument('cfile', help="File being copied")
accolade_copy.add_argument('cfolder', help="Place being copied")

accolade_list = accolade_subparser2.add_parser('list')
accolade_list.set_defaults(which='list')
accolade_list.add_argument('lfile', help="Directory of which the files will be listed")



accolade_remove = accolade_subparser2.add_parser('remove')
accolade_remove.set_defaults(which='remove')
accolade_remove.add_argument('rfile', help="File that will be deleted")

accolade_create = accolade_subparser2.add_parser('create')
accolade_create.set_defaults(which='create')
accolade_create.add_argument('cbuck', help="Bucket that will be created")


accolade_sync = accolade_subparser2.add_parser('sync')
accolade_sync.set_defaults(which='sync')
accolade_sync.add_argument('buck1', help="Bucket items are being copied from")
accolade_sync.add_argument('buck2', help="Bucket items are being copied into")

accolade_removebucket = accolade_subparser2.add_parser('removebucket')
accolade_removebucket.set_defaults(which="removebucket")
accolade_removebucket.add_argument('rembuck', help="Bucket that will be removed if it's empty")




args = vars(parser.parse_args())

which = args['which']


session = boto3.Session(profile_name='test')
s3res = session.resource('s3')
s3client = session.client('s3')


if which == 'list':
  os.system('aws s3 ls {} --profile test'.format(args['lfile']))

elif which == 'copy':
    os.system('aws s3 cp {} {} --profile test'.format(args['cfile'], args['cfolder']))

elif which == 'move':
    os.system('aws s3 mv {} {} --profile test'.format(args['mfile'], args['mfolder']))


elif which == 'create':
    os.system('aws s3 mb {} --profile test'.format(args['cbuck']))

elif which == 'sync':
    os.system('aws s3 sync {} {} --profile test'.format(args['buck1'], args['buck2']))


elif which == 'removebucket':
    os.system('aws s3 rb {} --profile test'.format(args['rembuck']))


elif which == 'remove':
    os.system('aws s3 rm {} --profile test'.format(args['rfile']))











import requests
import json
import getpass

token_url = "https://login-test3.myaccolade.com/token"

test_api_url = "api url should be here"


#Resource owner's credentials
username = input('Username: ' )
password = getpass.getpass('Passcode: ')
print(username)
print(password)
print('\n')

#client's credentials
client_id = 'etp-admin'
client_secret = 'AJ8t1jknpgd2flqM2-JAs3cIi3EV3Y02jk_WPeMl1LfGRSbZyoIiXx50rCPYbfHKTNgXDTOaE0xCpMwZpexbmIY'

# Single call with resource owner credentials in variable "data" and then client credentials in the "auth"
# Should return the access_token
data = {'grant_type': 'password', 'username': username, 'password': password}


# May have to include if not working:verify=False,
access_token_response = requests.post(token_url, data=data, allow_redirects=False, auth=(client_id, client_secret))

print("Lets now print the type of the access_token_response:")
print(type(access_token_response))
print('\n')
print("Here are the headers of the access_token_response:")
print(access_token_response.headers)
print('\n')
print("Now printing the type of the headers:")
print(type(access_token_response.headers))
print('\n')

print("Here are the text of the access_token_reponse:")
print(access_token_response.text)
print('\n')

tokens = json.loads(access_token_response.text)
print("let's now print the type of the tokens:")
print(type(tokens))
print('\n')
print("I am now printing the access token: " + "\n" + tokens['access_token'])
print('\n')
print("I am now printing the id token: " + "\n" + tokens['id_token'])



# Use access token to interact with grant
# print("Now starting to interact with the grant!")
# api_call_headers = {'Authorization': 'Bearer ' + tokens['access_token']}
# print(api_call_headers)
# api_call_response = requests.get(test_api_url, headers=api_call_headers, verify=False)
#
# print(api_call_response.text)


#!/usr/bin/env python3
#chmod +x "file name"
import argparse
import boto3
import os
import botocore

parser = argparse.ArgumentParser()
subparser = parser.add_subparsers()

# accolade_group = subparser.add_parser('accolade')
# accolade_subparser = accolade_group.add_subparsers()

# accolade_storage = accolade_subparser.add_parser('storage')
# accolade_subparser2 = accolade_storage.add_subparsers()
accolade_group = subparser.add_parser('storage')
accolade_subparser2 = accolade_group.add_subparsers()


accolade_move = accolade_subparser2.add_parser('move')
accolade_move.set_defaults(which='move')
accolade_move.add_argument('buck1', help="Bucket that files are moving from")
accolade_move.add_argument('buck2', help="Bucket that files are going to be placed into")

accolade_copy = accolade_subparser2.add_parser('copy')
accolade_copy.set_defaults(which='copy')
accolade_copy.add_argument('buck', help="Bucket location to be copied")
accolade_copy.add_argument('key', help="Key location to be copied")
accolade_copy.add_argument('buck2', help="File being copied")
accolade_copy.add_argument('key2', help="Place being copied")

accolade_list = accolade_subparser2.add_parser('list')
accolade_list.set_defaults(which='list')
accolade_list.add_argument('lbuck', help="Directory of which the files will be listed")

accolade_listall = accolade_subparser2.add_parser('listallbuck')
accolade_listall.set_defaults(which='listallbuck')


accolade_remove = accolade_subparser2.add_parser('remove')
accolade_remove.set_defaults(which='remove')
accolade_remove.add_argument('rbucket', help="Bucket of object to be removed")
accolade_remove.add_argument('rkey', help="Key within bucket to remove file")


accolade_create = accolade_subparser2.add_parser('create')
accolade_create.set_defaults(which='create')
accolade_create.add_argument('cbuck', help="Bucket that will be created")


accolade_sync = accolade_subparser2.add_parser('sync')
accolade_sync.set_defaults(which='sync')
accolade_sync.add_argument('buckname1', help="Name of bucket that items are being copied from")
accolade_sync.add_argument('buckname2', help="Name of bucket that items are being copied into")
accolade_sync.add_argument('path1', help="Path to directory that files are being copied from")
accolade_sync.add_argument('path2', help="Path to directory that files are being copied to")


accolade_upload = accolade_subparser2.add_parser('upload')
accolade_upload.set_defaults(which='upload')
accolade_upload.add_argument('file', help="File that will be upload into the bucket-key location")
accolade_upload.add_argument('bucket', help="Bucket that the file will be uploaded to")
accolade_upload.add_argument('key', help="Key that the file will be uploaded to")
accolade_upload.add_argument('--replace', help="Include on command line if replacing another file", action='store_true')


accolade_dirupload = accolade_subparser2.add_parser('dirupload')
accolade_dirupload.set_defaults(which='dirupload')
accolade_dirupload.add_argument('directory', help="Absolute path to the directory that will be copied")
accolade_dirupload.add_argument('bucketname', help="Bucket that files will be uploaded too")
accolade_dirupload.add_argument('key', help="Key that files will be uploaded to")

accolade_upload = accolade_subparser2.add_parser('replace')
accolade_upload.set_defaults(which='replace')
accolade_upload.add_argument('file', help="File that will be replacing its previous version")
accolade_upload.add_argument('repbucket', help="Bucket that the previous file was uploaded to")
accolade_upload.add_argument('repkey', help="Key that the previous file was uploaded to, Default to "" if not key")





args = vars(parser.parse_args())

which = args['which']

session = boto3.Session(profile_name='test')
s3res = session.resource('s3')
s3client = session.client('s3')


def uploadDirectory(path, bucketname, key):
    for root, dirs, files in os.walk(path):
        for file in files:
            local_path = os.path.join(root, file)
            relative_path = os.path.relpath(local_path, path)
            s3_path = os.path.join(key, relative_path)
            if file != '.DS_Store':
                s3client.upload_file(local_path, bucketname, s3_path)



if which == 'list':
  for object in s3res.Bucket(args['lbuck']).objects.all():
      print(object)

if which == 'listallbuck':
    listbucket = s3client.list_buckets()
    buckets = [bucket['Name'] for bucket in listbucket['Buckets']]
    for bucket in buckets:
        print(bucket)

# Should work- I just don't have access to do so
elif which == 'copy':
    copy_source = {
        'Bucket': 'buck',
        'Key': 'key'
    }
    s3client.copy(copy_source, 'buck2', 'key2')


elif which == 'move':
    src = s3res.Bucket(args['mfile'])
    dst = s3res.Bucket(args['mfolder'])
    for k in src.list():
        dst.copy_key(k.key.name, src.name, k.key.name)
        k.delete()

elif which == 'create':
    s3res.create_bucket(Bucket=args['cbuck'])


# Don't have permissions, but this should work
elif which == 'sync':
    # src = s3res.Bucket(args['buck1'])
    # dst = s3res.Bucket(args['buck2'])
    # for object in src.objects.all():
    #     file = object.key
    #     print(file)
    #     # if file not in dst.objects.all():
    #     #     s3client.upload_file(file, args['buck2'], '')
    old_bucket_name = args['buckname1']
    old_prefix = args['path1']
    new_bucket_name = args['buckname2']
    new_prefix = args['path2']
    old_bucket = s3res.Bucket(old_bucket_name)
    new_bucket = s3res.Bucket(new_bucket_name)

    for obj in old_bucket.objects.filter(Prefix=old_prefix):
        old_source = {'Bucket': old_bucket_name,
                      'Key': obj.key}
        new_key = obj.key.replace(old_prefix, new_prefix)
        new_obj = new_bucket.Object(new_key)
        new_obj.copy(old_source)

# For key, must put location/file name
elif which == 'upload':
    if args['replace']:
        try:
            s3res.Object(args['bucket'], args['key']).load()
            print("going to replace now!")
            s3res.Object(args['bucket'], args['key']).delete()
            s3client.upload_file(args['file'], args['bucket'], args['key'])
        except botocore.exceptions.ClientError:
            #For now pretending that accolade-platform-ext-dev-partners-577121982548 is makeup bucket
            print("Going into makeup bucket")
            s3client.upload_file(args['file'], 'accolade-platform-ext-dev-partners-577121982548', args['key'])
    else:
        s3client.upload_file(args['file'], args['bucket'], args['key'])




elif which == 'dirupload':
    uploadDirectory(args['directory'], args['bucketname'], args['key'])

elif which == 'replace':
    s3res.Object(args['repbucket'], args['repkey']).delete()
    s3client.upload_file(args['file'], args['repbucket'], args['repkey'])

elif which == 'remove':
    s3res.Object(args['rbucket'], args['rkey']).delete()




# This is a will eventually be used to restrict access to specific buckets
# aws s3api put-bucket-policy --bucket Test --policy file://policy.json
#
# policy.json:
# {
#    "Statement": [
#       {
#          "Effect": "Allow",
#          "Principal": "*",
#          "Action": "s3:GetObject",
#          "Resource": "arn:aws:s3:::Test/*"
#       },
#       {
#          "Effect": "Allow",
#          "Principal": {
#             "AWS": "arn:aws:iam::123456789012:root"
#          },
#          "Resource": "arn:aws:s3:::Test/*"
#       }
#    ]
# }


#!/usr/bin/env python3
# chmod +x "file name"
import getpass
import json
import hashlib
import requests
import argparse
import boto3
import os
import botocore
import time
import datetime
import logging
import pipdate

version = '3.0'


def checkforupdate():
    print("You are now using version 3.0")
    update = pipdate.check('accoladecli', version)
    if update is not "":
        logging.warning( 'This version of accoladecli is outdated. Re-install by typing "pip install accoladecli" on command line')

def run():
    parser = argparse.ArgumentParser()
    subparser = parser.add_subparsers()

    accolade_group = subparser.add_parser('storage')
    accolade_subparser2 = accolade_group.add_subparsers()

    accolade_remove = accolade_subparser2.add_parser('remove')
    accolade_remove.set_defaults(which='remove')
    # accolade_remove.add_argument('rbucket', help="Bucket of object to be removed")
    accolade_remove.add_argument('rkey', help="Key within bucket to remove file")

    accolade_upload = accolade_subparser2.add_parser('upload')
    accolade_upload.set_defaults(which='upload')
    accolade_upload.add_argument('file', help="File that will be upload into the bucket-key location")
    # accolade_upload.add_argument('bucket', help="Bucket that the file will be uploaded to")
    # accolade_upload.add_argument('key', help="Key that the file will be uploaded to")
    accolade_upload.add_argument('--replace', help="Include on command line if replacing another file",
                                 action='store_true')

    accolade_dirupload = accolade_subparser2.add_parser('dirupload')
    accolade_dirupload.set_defaults(which='dirupload')
    accolade_dirupload.add_argument('directory', help="Absolute path to the directory that will be copied")
    accolade_dirupload.add_argument('bucketname', help="Bucket that files will be uploaded too")
    accolade_dirupload.add_argument('key', help="Key that files will be uploaded to")

    args = vars(parser.parse_args())

    which = args['which']

    session = boto3.Session(profile_name='test')
    s3res = session.resource('s3')
    s3client = session.client('s3')

    def uploadDirectory(path, bucketname, key):
        for root, dirs, files in os.walk(path):
            for file in files:
                local_path = os.path.join(root, file)
                relative_path = os.path.relpath(local_path, path)
                s3_path = os.path.join(key, relative_path)
                if file != '.DS_Store':
                    s3client.upload_file(local_path, bucketname, s3_path)

    logging.basicConfig(format='%(message)s', level=logging.INFO)

    # Resource owner's credentials
    username = storedusername = input('Username: ')
    password = getpass.getpass('Passcode: ')
    logging.info(username)
    logging.info(password)
    logging.info('\n')

    def hashfunc(input):
        return hashlib.sha256('{}'.format(input).encode('utf-8')).hexdigest()

    # Storing data dictionary as a parameter for the Accolade token below
    data = {'grant_type': 'password', 'username': username, 'password': password}

    username = hashfunc(username)

    try:
        addon = '/' + args['file'].split('/')[-1]

    except:
        addon = '/' + args['rkey'].split('/')[-1]

    # One-way SSL(just server is certifie), Two-way SSL(both must have certifications), or some API gateway to have logging is necessary

    # For key, must put location/file name
    if which == 'upload':
        if args['replace']:
            try:
                s3res.Object('accolade-platform-ext-dev-partners-577121982548', 'Hashed/' + username + addon).load()
                logging.info("going to replace now!")
                s3res.Object('accolade-platform-ext-dev-partners-577121982548', 'Hashed/' + username).delete()
                s3client.upload_file(args['file'], 'accolade-platform-ext-dev-partners-577121982548',
                                     'Hashed/' + username + addon)
            except botocore.exceptions.ClientError:
                # For now pretending that accolade-platform-ext-dev-partners-577121982548 is makeup bucket
                logging.info("Going into makeup bucket")
                s3client.upload_file(args['file'], 'accolade-platform-ext-dev-partners-577121982548',
                                     'Hashed/' + username + addon)
        else:
            s3client.upload_file(args['file'], 'accolade-platform-ext-dev-partners-577121982548',
                                 'Hashed/' + username + addon)




    elif which == 'dirupload':
        uploadDirectory(args['directory'], args['bucketname'], args['key'])


    elif which == 'remove':
        s3res.Object('accolade-platform-ext-dev-partners-577121982548', 'Hashed/' + username + addon).delete()

    def logdata():
        timeatuse = time.time()
        formattedtime = datetime.datetime.fromtimestamp(timeatuse).strftime('%Y-%m-%d %H:%M:%S')

        action = which

        logdata = {'user': storedusername, 'date&time': formattedtime, 'filename': addon[1:], 'action': action}
        logging.info("I am now printing the log data: ")
        logging.info(logdata)
        logging.info('\n')

    logdata()

    # Now going to get Accolade token
    client_id = 'etp-admin'
    client_secret = 'AJ8t1jknpgd2flqM2-JAs3cIi3EV3Y02jk_WPeMl1LfGRSbZyoIiXx50rCPYbfHKTNgXDTOaE0xCpMwZpexbmIY'

    token_url = "https://login-test3.myaccolade.com/token"

    access_token_response = requests.post(token_url, data=data, allow_redirects=False, auth=(client_id, client_secret))

    logging.info("Lets now print the type of the access_token_response:")
    logging.info(type(access_token_response))
    logging.info('\n')
    logging.info("Here are the headers of the access_token_response:")
    logging.info(access_token_response.headers)
    logging.info('\n')
    logging.info("Now printing the type of the headers:")
    logging.info(type(access_token_response.headers))
    logging.info('\n')

    logging.info("Here are the text of the access_token_reponse:")
    logging.info(access_token_response.text)
    logging.info('\n')

    tokens = json.loads(access_token_response.text)
    logging.info("let's now print the type of the tokens:")
    logging.info(type(tokens))
    logging.info('\n')
    logging.info("I am now printing the access token: " + "\n" + tokens['access_token'])
    logging.info('\n')
    logging.info("I am now printing the id token: " + "\n" + tokens['id_token'])
    logging.info('\n')

    # Now trading off with AWS STS

    client = boto3.client('sts')
    token = "eyJraWQiOiJyc2ExIiwiYWxnIjoiUlMyNTYifQ.eyJzdWIiOiJjZDg5M2I2Yy04YTYzLTRmNTgtOTAxYi01ZDA0YWU4NzExZmUiLCJhdWQiOiJldHAtYWRtaW4iLCJraWQiOiJyc2ExIiwiaXNzIjoiaHR0cHM6XC9cL2xvZ2luLXRlc3QzLm15YWNjb2xhZGUuY29tXC8iLCJleHAiOjE1MzE3NjM4MDIsImlhdCI6MTUzMTc2MzIwMiwianRpIjoiMzRiYjRiYjAtM2UyZS00YThjLTlhYjItNzg1MDgzMDFjODNkIn0.QykzGp7u87Y0JQS6Fl0TUCbF-N73LXXnFNLdD6xpDL4T4M58P7KeQ9OkYCw9xlBhwk3JzfhQ8Iqf__eU0NFql97UyGHi3eCQ-zNuQVya1UdidL1tBpTCJZrEzYhzHmNM2BWd7Mlb1pwSj_qyaoOTrx-POyik25NoH5VBM4XXLqehkQK3sBWN-vSPPEJZgFWzfraCtKrrnzoI9Sxx5tuxsd2ABD91quLfwsBkbxdW3ax56QMz8CF3D42RqxvDi388-SQA7JphLhoIS7dlGz3cQRXv8MkyeXptGvVFtdu2QgGAUoGL3_oJpmkrsKMdJKvcRKBa2AbiG-KuzqqyYTImkw"

    uh = hashfunc('UnitedHealth')
    at = hashfunc('Aetna')
    ks = hashfunc('Kaiser')
    ws = hashfunc('Wellpoint')

    username = hashfunc(username)

    jsonrestr = {
        "Id": "S3PolicyRestrictions",
        "Statement": [
            {
                "Sid": "IPDeny",
                "Effect": "Deny",
                "Principal": {
                    "AWS": "*"
                },
                "Action": "s3:*",
                "Resource": "*",
                "Condition": {
                    "NotIpAddress": {
                        "aws:SourceIp": "72.309.38.2/32"
                        # "aws:SourceIp": ["72.309.38.2/32", "Insert more IP's here in list format"]
                        # Accolade's IP Address- 50.251.254.133

                    }
                }
            },
            {
                "Sid": "KeyAllow",
                "Effect": "Allow",
                "Principal": "*",
                "Action": "s3:*",
                "Resource": ["arn:aws:s3:::examplebucket/" + uh, "arn:aws:s3:::examplebucket/" + at,
                             "arn:aws:s3:::examplebucket/" + ks,
                             "arn:aws:s3:::examplebucket/" + ws],
                # End product would be something like "arn:aws:s3:::examplebucket/" + username
            }
        ]
    }

    policyrestr = json.dumps(jsonrestr)

    assumed_role_object = client.assume_role_with_web_identity(
        # RoleArn="arn:aws:iam::ACCOUNT-ID-WITHOUT-HYPHENS:role/ROLE-NAME",
        RoleArn="arn:aws:iam::vikramchandran:role/user-pegasus",
        RoleSessionName="practicesession", WebIdentityToken=token)

    accesskey = assumed_role_object['Credentials']['AccessKeyId']
    secretaccesskey = assumed_role_object['Credentials']['SecretAccessKey']
    sessiontoken = assumed_role_object['Credentials']['SessionToken']

    logging.info("Credentials are: " + "\n")
    logging.info("AccessKey Id: %s" % accesskey)
    logging.info("SecretAccessKey: %s" % secretaccesskey)
    logging.info("SessionToken: %s" % sessiontoken)

    session = boto3.Session(profile_name='test', aws_access_key_id=accesskey, aws_secret_access_key=secretaccesskey,
                            aws_session_token=sessiontoken)


if __name__ == 'main':
    checkforupdate()
    run()

#Then add all the master code as below


import urllib, json
import hashlib
import boto3



client = boto3.client('sts')

def hashfunc(input):
    return hashlib.sha256('{}'.format(input).encode('utf-8')).hexdigest()


token = "eyJraWQiOiJyc2ExIiwiYWxnIjoiUlMyNTYifQ.eyJzdWIiOiJjZDg5M2I2Yy04YTYzLTRmNTgtOTAxYi01ZDA0YWU4NzExZmUiLCJhdWQiOiJldHAtYWRtaW4iLCJraWQiOiJyc2ExIiwiaXNzIjoiaHR0cHM6XC9cL2xvZ2luLXRlc3QzLm15YWNjb2xhZGUuY29tXC8iLCJleHAiOjE1MzE3NjM4MDIsImlhdCI6MTUzMTc2MzIwMiwianRpIjoiMzRiYjRiYjAtM2UyZS00YThjLTlhYjItNzg1MDgzMDFjODNkIn0.QykzGp7u87Y0JQS6Fl0TUCbF-N73LXXnFNLdD6xpDL4T4M58P7KeQ9OkYCw9xlBhwk3JzfhQ8Iqf__eU0NFql97UyGHi3eCQ-zNuQVya1UdidL1tBpTCJZrEzYhzHmNM2BWd7Mlb1pwSj_qyaoOTrx-POyik25NoH5VBM4XXLqehkQK3sBWN-vSPPEJZgFWzfraCtKrrnzoI9Sxx5tuxsd2ABD91quLfwsBkbxdW3ax56QMz8CF3D42RqxvDi388-SQA7JphLhoIS7dlGz3cQRXv8MkyeXptGvVFtdu2QgGAUoGL3_oJpmkrsKMdJKvcRKBa2AbiG-KuzqqyYTImkw"


uh = hashfunc('UnitedHealth')
at = hashfunc('Aetna')
ks = hashfunc('Kaiser')
ws = hashfunc('Wellpoint')



jsonrestr = {
   "Id": "S3PolicyRestrictions",
   "Statement": [
       {
           "Sid": "IPDeny",
           "Effect": "Deny",
           "Principal": {
               "AWS": "*"
           },
           "Action": "s3:*",
           "Resource": "*",
           "Condition": {
               "NotIpAddress": {
                   "aws:SourceIp": "72.309.38.2/32"
                   # "aws:SourceIp": ["72.309.38.2/32", "Insert more IP's here in list format"]

               }
           }
       },
       {
      "Sid": "IPAllow",
      "Effect": "Allow",
      "Principal": "*",
      "Action": "s3:*",
      "Resource": ["arn:aws:s3:::examplebucket/uh", "arn:aws:s3:::examplebucket/at", "arn:aws:s3:::examplebucket/ks",
             "arn:aws:s3:::examplebucket/ws"],
       }
   ]
}

policyrestr = json.dumps(jsonrestr)


assumed_role_object = client.assume_role_with_web_identity(
   # RoleArn="arn:aws:iam::ACCOUNT-ID-WITHOUT-HYPHENS:role/ROLE-NAME",
    RoleArn="arn:aws:iam::vikramchandran:role/user-pegasus",
    RoleSessionName="practicesession", WebIdentityToken=token)



accesskey = assumed_role_object['Credentials']['AccessKeyId']
secretaccesskey = assumed_role_object['Credentials']['SecretAccessKey']
sessiontoken = assumed_role_object['Credentials']['SessionToken']

print("Credentials are: " + "\n")
print("AccessKey Id: %s" % accesskey)
print("SecretAccessKey: %s" % secretaccesskey)
print("SessionToken: %s" % sessiontoken)

session = boto3.Session(profile_name='test', aws_access_key_id=accesskey, aws_secret_access_key=secretaccesskey, aws_session_token=sessiontoken)

# Then add all the master code as below


def url_conversion(assumed_role_object):
    # Converting to JSON format
    json_string_with_temp_credentials = '{'
    json_string_with_temp_credentials += '"sessionId":"' + assumed_role_object['Credentials']['AccessKeyId'] + '",'
    json_string_with_temp_credentials += '"sessionKey":"' + assumed_role_object['Credentials']['SecretAccessKey'] + '",'
    json_string_with_temp_credentials += '"sessionToken":"' + assumed_role_object['Credentials']['SessionToken'] + '"'
    json_string_with_temp_credentials += '}'

    request_parameters = "?Action=getSigninToken"
    request_parameters += "&SessionDuration=43200"
    request_parameters += "&Session=" + urllib.quote_plus(json_string_with_temp_credentials)
    request_url = "https://signin.aws.amazon.com/federation" + request_parameters
    r = requests.get(request_url)

    # Returns a JSON document with a single element named SigninToken.
    signin_token = json.loads(r.text)

    request_parameters = "?Action=login"
    request_parameters += "&Issuer=Example.org"
    request_parameters += "&Destination=" + urllib.quote_plus("https://console.aws.amazon.com/")
    request_parameters += "&SigninToken=" + signin_token["SigninToken"]
    request_url = "https://signin.aws.amazon.com/federation" + request_parameters
    return request_url

# This in the bottom for other ways to restrict IP addresses

# {
#   "Version": "2012-10-17",
#   "Id": "S3PolicyId1",
#   "Statement": [
#     {
#       "Sid": "IPAllow",
#       "Effect": "Allow",
#       "Principal": "*",
#       "Action": "s3:*",
#       "Resource": "arn:aws:s3:::examplebucket/*",
#       "Condition": {
#          "IpAddress": {"aws:SourceIp": "54.240.143.0/24"},
#          "NotIpAddress": {"aws:SourceIp": "54.240.143.188/32"}
#       }
#     }
#   ]
# }





from setuptools import setup
import importlib.machinery as mh


helper = mh.SourceFileLoader('accolade', '/Users/vikram.chandran/Desktop/Repos/accoladecli/cliparser/accolade')
accolade = helper.load_module()

version_num = accolade.version
print(version_num)


setup(name='accoladecli', version = version_num, packages = ['cliparser'], author= 'J.V.', description= 'Accolade CLI',
      scripts=['cliparser/accolade'], install_requires= ['boto3', 'botocore', 'pipdate'])



import argparse
import os
import boto3

#Create an argument cliparser
parser = argparse.ArgumentParser()



def usoptionals():
    # Add all the optional and required arguments on the command line
    parser.add_argument('--file', help="File being moved")
    parser.add_argument('--folder', help="Place being added")
    parser.add_argument('command', help="Command to be executed on CLI")
    parser.add_argument('--filerem', help="File going to be removed")
    parser.add_argument('--newbucket', help="Create a new bucket")
    parser.add_argument('--listitems', help="List the items in a file", default="")
    parser.add_argument('--syncbuck1', help="First bucket to sync")
    parser.add_argument('--syncbuck2', help="Second bucket to sync")
    parser.add_argument('--emptybuck', help="Remove an empty bucket")
    parser.add_argument('--bucket', help="This is a bucket that has a variety of purposes")
    parser.add_argument('--othbucket', help="This is the bucket to upload files into")
    parser.add_argument('--key', help="This is the path within a bucket")
    parser.add_argument('--othkey', help="This is the path within a bucket")

    parser.add_argument('--emptybuck', help="Remove an empty bucket")
    parser.add_argument('--bucket', help="This is a bucket that has a variety of purposes")
    parser.add_argument('--othbucket', help="This is the bucket to upload files into")
    parser.add_argument('--key', help="This is the path within a bucket")
    parser.add_argument('--othkey', help="This is the path within a bucket")



#useoptionals()

# Set all the command-line arguments to respective variables for testing
# Uncomment only if using useoptionals()

# args = cliparser.parse_args()
# fl = args.file
# flder = args.folder
# flrem = args.filerem
# cmd = args.command
# newbuck = args.newbucket
# list = args.listitems
# buck_1 = args.syncbuck1
# buck_2 = args.syncbuck2
# empbuck = args.emptybuck
# buck = args.bucket
# ky = args.key
# othbuck = args.othbucket
# othky = args.othkey



#Print out all the arguments on the command for testing; usually defaults to "None"
# Uncomment only if using useoptionals()

# print(fl)
# print(flder)
# print(cmd)
# print(newbuck)
# print(list)
# print(buck_1)
# print(buck_2)
# print(empbuck)
# print(buck)
# print(ky)
# print(othbuck)


def ogcommandline():

    #'move' is to move, 'copy' is to copy
    if cmd == 'move':
        os.system('aws s3 {} {} {} --profile test '.format('mv', fl, flder))
    if cmd == 'copy':
        os.system('aws s3 {} {} {} --profile test '.format('cp', fl, flder))
    #'remove' is to remove
    elif cmd == 'remove':
        os.system('aws s3 {} {} --profile test '.format('rm', flrem))
    #'create' is to create a new bucket(credentials are required)
    elif cmd == 'create':
        os.system('aws s3 {} {} --profile test '.format('mb', newbuck))
    #'list' lists the items within a bucket or folder
    elif cmd == 'list':
        os.system('aws s3 {} {} --profile test '.format('ls', list))
    #'sync' basically recursively copies all directories from buck_1 to buck_2
    elif cmd == 'sync':
        os.system('aws s3 {} {} {} --profile test '.format(cmd, buck_1, buck_2))
    #'removebuck' will remove an empty bucket
    elif cmd == 'removebuck':
        os.system('aws s3 {} {} --profile test '.format('rb', empbuck))



parser = argparse.ArgumentParser()
subparser = parser.add_subparsers()

accolade_group = subparser.add_parser('accolade-cli')
accolade_subparser = accolade_group.add_subparsers()

accolade_storage = accolade_subparser.add_parser('storage')
accolade_subparser2 = accolade_storage.add_subparsers()

accolade_move = accolade_subparser2.add_parser('move')
accolade_move.add_argument('mfile', help="File being moved")
accolade_move.add_argument('mfolder', help="Place being added")

accolade_copy = accolade_subparser2.add_parser('copy')
accolade_copy.add_argument('cfile', help="File being copied")
accolade_copy.add_argument('cfolder', help="Place being copied")

accolade_list = accolade_subparser2.add_parser('list')
accolade_list.add_argument('lfile', help="Directory of which the files will be listed")

accolade_remove = accolade_subparser2.add_parser('remove')
accolade_remove.add_argument('rfile', help="File that will be deleted")

accolade_create = accolade_subparser2.add_parser('create')
accolade_create.add_argument('cbuck', help="Bucket that will be created")


accolade_sync = accolade_subparser2.add_parser('sync')
accolade_sync.add_argument('buck1', help="Bucket items are being copied from")
accolade_sync.add_argument('buck2', help="Bucket items are being copied into")

accolade_removebucket = accolade_subparser2.add_parser('removebucket')
accolade_removebucket.add_argument('rembuck', help="Bucket that will be removed if it's empty")



args = parser.parse_args()

def errorhandling():
    try:
        # 'move' is to move
        if args.mfile:
            os.system('aws s3 mv {} {} --profile test '.format(args.mfile, args.mfolder))
    except:
        try:
            # 'copy' is to copy
            if args.cfile:
                os.system('aws s3 cp {} {} --profile test '.format(args.cfile, args.cfolder))
        except:
            try:
                # 'list' lists the items within a bucket or folder
                if args.lfile:
                    os.system('aws s3 ls {} --profile test '.format(args.list))
            except:
                try:
                    if args.rfile:
                        os.system('aws s3 rm {} --profile test '.format(args.rfile))
                except:
                    try:
                        if args.cbuck:
                            os.system('aws s3 mb {} --profile test '.format(args.cbuck))
                    except:
                        try:
                            if args.buck1:
                                os.system('aws s3 sync {} {} --profile test '.format(args.buck1, args.buck2))
                        except:
                            try:
                                if args.rembuck:
                                    os.system('aws s3 rb {} --profile test '.format(args.rembuck))
                            except:
                                pass



#Use os library to run AWS CLI in this python script by passing in the command-line arguments
#There are some interesting rules between required or optional
def commandline():

    # 'move' is to move
    if args.mfile:
        os.system('aws s3 mv {} {} --profile test '.format(args.mfile, args.mfolder))

    # 'copy' is to copy
    elif args.cfile:
        os.system('aws s3 cp {} {} --profile test '.format(args.cfile, args.cfolder))

    # 'list' lists the items within a bucket or folder
    elif args.lfile:
        os.system('aws s3 ls {} --profile test '.format(args.lfile))

    #'remove' is to remove
    elif args.rfile:
        os.system('aws s3 {} --profile test '.format(args.rfile))

    #'create' is to create a new bucket(credentials are required)
    elif args.create:
        os.system('aws s3 mb {} --profile test '.format(args.cbuck))

    #'sync' basically recursively copies all directories from buck_1 to buck_2
    elif args.syncfile:
        os.system('aws s3 sync {} {} --profile test '.format( args.buck1, args.buck2))

    #'removebuck' will remove an empty bucket
    elif args.rembuck:
        os.system('aws s3 rm {} --profile test '.format(args.rembuck))

#commandline()

def useboto():
    # Creating Boto objects to replicate everything on top without OS but instead Boto
    session = boto3.Session(profile_name='test')
    s3res = session.resource('s3')
    s3client = session.client('s3')

    # Creates a new bucket
    if cmd == 'create':
        s3res.create_bucket(Bucket=buck)

    # Key must be like Vikram/file1.txt
    if cmd == 'up':
        s3client.upload_file(fl, buck, ky)

    # Othkey must also be like Jai/file2.txt
    if cmd == 'copy':
        copy_source = {
            'Bucket': buck,
            'Key': ky
        }
        s3client.copy(copy_source, othbuck, othky)

    # Download object at bucket-name with key-name to file
    if cmd == 'download':
        s3client.download_file(buck, ky, fl)

    # Lists all the buckets
    if cmd == 'ls':
        listbuckets = s3client.list_buckets()
        buckets = [bucket['Name'] for bucket in listbuckets['Buckets']]
        print("Bucket List: %s" % buckets)